pub struct Query<'a> { /* private fields */ }Expand description
State for font selection.
Instances of this can be obtained from Collection::query.
Implementations
Sourceimpl<'a> Query<'a>
impl<'a> Query<'a>
Sourcepub fn set_families<'f, I>(&mut self, families: I)
pub fn set_families<'f, I>(&mut self, families: I)
Sets the ordered sequence of families to match against.
Sourcepub fn set_attributes(&mut self, attributes: Attributes)
pub fn set_attributes(&mut self, attributes: Attributes)
Sets the primary attributes to match against.
Sourcepub fn set_fallbacks(&mut self, key: impl Into<FallbackKey>)
pub fn set_fallbacks(&mut self, key: impl Into<FallbackKey>)
Sets the script and locale for fallback fonts.
Sourcepub fn matches_with(&mut self, f: impl FnMut(&QueryFont) -> QueryStatus)
pub fn matches_with(&mut self, f: impl FnMut(&QueryFont) -> QueryStatus)
Invokes the given callback with all fonts that match the current settings.
Return QueryStatus::Stop to end iterating over the matching
fonts or QueryStatus::Continue to continue iterating.